@@ -1,5 +1,7 @@
 from math import gcd, isqrt
 from random import randrange
+import ctypes
+import pathlib
 
 from cryptography318.bailliepsw_helper import LucasPseudoPrime, D_chooser
 
